Workflow
========

``Workflow`` is a simple python library to handle finite state machines, a.k.a objects that always have a
state amongst a finite list of possible states and transitions between those states.

.. image:: https://travis-ci.org/python-edgy/workflow.svg?branch=master
    :target: https://travis-ci.org/python-edgy/workflow

.. image:: https://readthedocs.org/projects/edgyworkflow/badge/?version=latest
    :target: http://edgyworkflow.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation Status

Install
:::::::

.. code-block:: shell

    pip install edgy.workflow
